@@ -228,7 +228,9 @@ static const TEXT* const impl_implementation[] =
 	"Firebird/linux SHEB",			// 81
 	"Firebird/linux HPPA",			// 82
 	"Firebird/linux ALPHA",			// 83
-	"Firebird/linux ARM64"			// 84
+	"Firebird/linux ARM64",			// 84
+	"Firebird/linux PPC64EL"		// 85
+
 };
 
 
